#include  <volume_io/internal_volume_io.h>
#include  <bicpl/marching_cube_data.h>
#include  <bicpl/marching.h>

private  marching_cube_data_struct  marching_cube_cases[256] =
    {
        {            /* 0 */
            0,
            {
{{0}}
            }
        },
        {            /* 1 */
            1,
            {
                { {0,0,0}, 2 },
                { {0,0,0}, 1 },
                { {0,0,0}, 0 }
            }
        },
        {            /* 2 */
            1,
            {
                { {0,0,0}, 0 },
                { {1,0,0}, 1 },
                { {1,0,0}, 2 }
            }
        },
        {            /* 3 */
            2,
            {
                { {0,0,0}, 2 },
                { {0,0,0}, 1 },
                { {1,0,0}, 1 },
                { {0,0,0}, 2 },
                { {1,0,0}, 1 },
                { {1,0,0}, 2 }
            }
        },
        {            /* 4 */
            1,
            {
                { {0,0,0}, 1 },
                { {0,1,0}, 2 },
                { {0,1,0}, 0 }
            }
        },
        {            /* 5 */
            2,
            {
                { {0,0,0}, 2 },
                { {0,1,0}, 0 },
                { {0,0,0}, 0 },
                { {0,0,0}, 2 },
                { {0,1,0}, 2 },
                { {0,1,0}, 0 }
            }
        },
        {            /* 6 */
            2,
            {
                { {0,1,0}, 2 },
                { {0,1,0}, 0 },
                { {0,0,0}, 1 },
                { {0,0,0}, 0 },
                { {1,0,0}, 1 },
                { {1,0,0}, 2 }
            }
        },
        {            /* 7 */
            3,
            {
                { {0,1,0}, 0 },
                { {1,0,0}, 1 },
                { {1,0,0}, 2 },
                { {0,1,0}, 0 },
                { {1,0,0}, 2 },
                { {0,1,0}, 2 },
                { {0,1,0}, 2 },
                { {1,0,0}, 2 },
                { {0,0,0}, 2 }
            }
        },
        {            /* 8 */
            1,
            {
                { {0,1,0}, 0 },
                { {1,1,0}, 2 },
                { {1,0,0}, 1 }
            }
        },
        {            /* 9 */
            2,
            {
                { {0,0,0}, 2 },
                { {0,0,0}, 1 },
                { {0,0,0}, 0 },
                { {0,1,0}, 0 },
                { {1,1,0}, 2 },
                { {1,0,0}, 1 }
            }
        },
        {            /* 10 */
            2,
            {
                { {0,0,0}, 0 },
                { {1,1,0}, 2 },
                { {1,0,0}, 2 },
                { {0,0,0}, 0 },
                { {0,1,0}, 0 },
                { {1,1,0}, 2 }
            }
        },
        {            /* 11 */
            3,
            {
                { {0,0,0}, 1 },
                { {0,1,0}, 0 },
                { {1,1,0}, 2 },
                { {0,0,0}, 1 },
                { {1,1,0}, 2 },
                { {0,0,0}, 2 },
                { {0,0,0}, 2 },
                { {1,1,0}, 2 },
                { {1,0,0}, 2 }
            }
        },
        {            /* 12 */
            2,
            {
                { {0,0,0}, 1 },
                { {0,1,0}, 2 },
                { {1,1,0}, 2 },
                { {0,0,0}, 1 },
                { {1,1,0}, 2 },
                { {1,0,0}, 1 }
            }
        },
        {            /* 13 */
            3,
            {
                { {0,0,0}, 0 },
                { {1,1,0}, 2 },
                { {1,0,0}, 1 },
                { {0,0,0}, 0 },
                { {0,0,0}, 2 },
                { {1,1,0}, 2 },
                { {0,0,0}, 2 },
                { {0,1,0}, 2 },
                { {1,1,0}, 2 }
            }
        },
        {            /* 14 */
            3,
            {
                { {0,0,0}, 1 },
                { {1,0,0}, 2 },
                { {0,0,0}, 0 },
                { {0,0,0}, 1 },
                { {0,1,0}, 2 },
                { {1,0,0}, 2 },
                { {0,1,0}, 2 },
                { {1,1,0}, 2 },
                { {1,0,0}, 2 }
            }
        },
        {            /* 15 */
            2,
            {
                { {0,0,0}, 2 },
                { {0,1,0}, 2 },
                { {1,0,0}, 2 },
                { {1,0,0}, 2 },
                { {0,1,0}, 2 },
                { {1,1,0}, 2 }
            }
        },
        {            /* 16 */
            1,
            {
                { {0,0,0}, 2 },
                { {0,0,1}, 0 },
                { {0,0,1}, 1 }
            }
        },
        {            /* 17 */
            2,
            {
                { {0,0,0}, 1 },
                { {0,0,0}, 0 },
                { {0,0,1}, 0 },
                { {0,0,0}, 1 },
                { {0,0,1}, 0 },
                { {0,0,1}, 1 }
            }
        },
        {            /* 18 */
            2,
            {
                { {0,0,1}, 1 },
                { {0,0,0}, 2 },
                { {0,0,1}, 0 },
                { {0,0,0}, 0 },
                { {1,0,0}, 1 },
                { {1,0,0}, 2 }
            }
        },
        {            /* 19 */
            3,
            {
                { {0,0,1}, 0 },
                { {1,0,0}, 1 },
                { {1,0,0}, 2 },
                { {0,0,1}, 0 },
                { {0,0,1}, 1 },
                { {1,0,0}, 1 },
                { {0,0,1}, 1 },
                { {0,0,0}, 1 },
                { {1,0,0}, 1 }
            }
        },
        {            /* 20 */
            2,
            {
                { {0,0,1}, 0 },
                { {0,0,1}, 1 },
                { {0,0,0}, 2 },
                { {0,0,0}, 1 },
                { {0,1,0}, 2 },
                { {0,1,0}, 0 }
            }
        },
        {            /* 21 */
            3,
            {
                { {0,0,1}, 1 },
                { {0,1,0}, 2 },
                { {0,1,0}, 0 },
                { {0,0,1}, 1 },
                { {0,1,0}, 0 },
                { {0,0,1}, 0 },
                { {0,0,1}, 0 },
                { {0,1,0}, 0 },
                { {0,0,0}, 0 }
            }
        },
        {            /* 22 */
            3,
            {
                { {1,0,0}, 1 },
                { {1,0,0}, 2 },
                { {0,0,0}, 0 },
                { {0,1,0}, 0 },
                { {0,0,0}, 1 },
                { {0,1,0}, 2 },
                { {0,0,1}, 0 },
                { {0,0,1}, 1 },
                { {0,0,0}, 2 }
            }
        },
        {            /* 23 */
            4,
            {
                { {0,0,1}, 1 },
                { {0,1,0}, 2 },
                { {0,1,0}, 0 },
                { {0,0,1}, 1 },
                { {0,1,0}, 0 },
                { {0,0,1}, 0 },
                { {0,0,1}, 0 },
                { {0,1,0}, 0 },
                { {1,0,0}, 1 },
                { {0,0,1}, 0 },
                { {1,0,0}, 1 },
                { {1,0,0}, 2 }
            }
        },
        {            /* 24 */
            2,
            {
                { {0,0,0}, 2 },
                { {0,0,1}, 0 },
                { {0,0,1}, 1 },
                { {0,1,0}, 0 },
                { {1,1,0}, 2 },
                { {1,0,0}, 1 }
            }
        },
        {            /* 25 */
            3,
            {
                { {0,0,1}, 1 },
                { {0,0,0}, 0 },
                { {0,0,1}, 0 },
                { {0,0,1}, 1 },
                { {0,0,0}, 1 },
                { {0,0,0}, 0 },
                { {1,1,0}, 2 },
                { {1,0,0}, 1 },
                { {0,1,0}, 0 }
            }
        },
        {            /* 26 */
            3,
            {
                { {0,1,0}, 0 },
                { {1,1,0}, 2 },
                { {1,0,0}, 2 },
                { {0,1,0}, 0 },
                { {1,0,0}, 2 },
                { {0,0,0}, 0 },
                { {0,0,1}, 1 },
                { {0,0,0}, 2 },
                { {0,0,1}, 0 }
            }
        },
        {            /* 27 */
            4,
            {
                { {0,0,0}, 1 },
                { {0,0,1}, 0 },
                { {0,0,1}, 1 },
                { {0,0,1}, 0 },
                { {0,0,0}, 1 },
                { {1,1,0}, 2 },
                { {0,0,0}, 1 },
                { {0,1,0}, 0 },
                { {1,1,0}, 2 },
                { {0,0,1}, 0 },
                { {1,1,0}, 2 },
                { {1,0,0}, 2 }
            }
        },
        {            /* 28 */
            3,
            {
                { {1,0,0}, 1 },
                { {0,1,0}, 2 },
                { {1,1,0}, 2 },
                { {1,0,0}, 1 },
                { {0,0,0}, 1 },
                { {0,1,0}, 2 },
                { {0,0,1}, 0 },
                { {0,0,1}, 1 },
                { {0,0,0}, 2 }
            }
        },
        {            /* 29 */
            4,
            {
                { {0,0,0}, 0 },
                { {0,0,1}, 0 },
                { {0,0,1}, 1 },
                { {0,0,1}, 1 },
                { {1,1,0}, 2 },
                { {0,0,0}, 0 },
                { {0,0,0}, 0 },
                { {1,1,0}, 2 },
                { {1,0,0}, 1 },
                { {0,0,1}, 1 },
                { {0,1,0}, 2 },
                { {1,1,0}, 2 }
            }
        },
        {            /* 30 */
            4,
            {
                { {0,0,0}, 2 },
                { {0,0,1}, 0 },
                { {0,0,1}, 1 },
                { {0,0,0}, 1 },
                { {1,0,0}, 2 },
                { {0,0,0}, 0 },
                { {0,0,0}, 1 },
                { {0,1,0}, 2 },
                { {1,0,0}, 2 },
                { {0,1,0}, 2 },
                { {1,1,0}, 2 },
                { {1,0,0}, 2 }
            }
        },
        {            /* 31 */
            3,
            {
                { {0,0,1}, 1 },
                { {1,0,0}, 2 },
                { {0,0,1}, 0 },
                { {0,0,1}, 1 },
                { {0,1,0}, 2 },
                { {1,0,0}, 2 },
                { {0,1,0}, 2 },
                { {1,1,0}, 2 },
                { {1,0,0}, 2 }
            }
        },
        {            /* 32 */
            1,
            {
                { {0,0,1}, 0 },
                { {1,0,0}, 2 },
                { {1,0,1}, 1 }
            }
        },
        {            /* 33 */
            2,
            {
                { {0,0,0}, 1 },
                { {0,0,0}, 0 },
                { {0,0,0}, 2 },
                { {0,0,1}, 0 },
                { {1,0,0}, 2 },
                { {1,0,1}, 1 }
            }
        },
        {            /* 34 */
            2,
            {
                { {0,0,0}, 0 },
                { {1,0,0}, 1 },
                { {1,0,1}, 1 },
                { {0,0,0}, 0 },
                { {1,0,1}, 1 },
                { {0,0,1}, 0 }
            }
        },
        {            /* 35 */
            3,
            {
                { {0,0,0}, 2 },
                { {1,0,1}, 1 },
                { {0,0,1}, 0 },
                { {0,0,0}, 2 },
                { {0,0,0}, 1 },
                { {1,0,1}, 1 },
                { {0,0,0}, 1 },
                { {1,0,0}, 1 },
                { {1,0,1}, 1 }
            }
        },
        {            /* 36 */
            2,
            {
                { {0,0,0}, 1 },
                { {0,1,0}, 2 },
                { {0,1,0}, 0 },
                { {0,0,1}, 0 },
                { {1,0,0}, 2 },
                { {1,0,1}, 1 }
            }
        },
        {            /* 37 */
            3,
            {
                { {0,1,0}, 2 },
                { {0,1,0}, 0 },
                { {0,0,0}, 0 },
                { {0,1,0}, 2 },
                { {0,0,0}, 0 },
                { {0,0,0}, 2 },
                { {1,0,1}, 1 },
                { {0,0,1}, 0 },
                { {1,0,0}, 2 }
            }
        },
        {            /* 38 */
            3,
            {
                { {0,0,1}, 0 },
                { {1,0,0}, 1 },
                { {1,0,1}, 1 },
                { {0,0,1}, 0 },
                { {0,0,0}, 0 },
                { {1,0,0}, 1 },
                { {0,1,0}, 2 },
                { {0,1,0}, 0 },
                { {0,0,0}, 1 }
            }
        },
        {            /* 39 */
            4,
            {
                { {0,0,0}, 2 },
                { {0,1,0}, 2 },
                { {0,1,0}, 0 },
                { {0,1,0}, 0 },
                { {1,0,1}, 1 },
                { {0,0,0}, 2 },
                { {0,0,0}, 2 },
                { {1,0,1}, 1 },
                { {0,0,1}, 0 },
                { {0,1,0}, 0 },
                { {1,0,0}, 1 },
                { {1,0,1}, 1 }
            }
        },
        {            /* 40 */
            2,
            {
                { {0,0,1}, 0 },
                { {1,0,0}, 2 },
                { {1,0,1}, 1 },
                { {1,0,0}, 1 },
                { {0,1,0}, 0 },
                { {1,1,0}, 2 }
            }
        },
        {            /* 41 */
            3,
            {
                { {0,0,0}, 1 },
                { {0,0,0}, 0 },
                { {0,0,0}, 2 },
                { {0,1,0}, 0 },
                { {1,1,0}, 2 },
                { {1,0,0}, 1 },
                { {0,0,1}, 0 },
                { {1,0,0}, 2 },
                { {1,0,1}, 1 }
            }
        },
        {            /* 42 */
            3,
            {
                { {1,0,1}, 1 },
                { {0,1,0}, 0 },
                { {1,1,0}, 2 },
                { {1,0,1}, 1 },
                { {0,0,1}, 0 },
                { {0,1,0}, 0 },
                { {0,0,1}, 0 },
                { {0,0,0}, 0 },
                { {0,1,0}, 0 }
            }
        },
        {            /* 43 */
            4,
            {
                { {1,0,1}, 1 },
                { {0,1,0}, 0 },
                { {1,1,0}, 2 },
                { {1,0,1}, 1 },
                { {0,0,1}, 0 },
                { {0,1,0}, 0 },
                { {0,0,1}, 0 },
                { {0,0,0}, 1 },
                { {0,1,0}, 0 },
                { {0,0,1}, 0 },
                { {0,0,0}, 2 },
                { {0,0,0}, 1 }
            }
        },
        {            /* 44 */
            3,
            {
                { {0,0,0}, 1 },
                { {0,1,0}, 2 },
                { {1,1,0}, 2 },
                { {0,0,0}, 1 },
                { {1,1,0}, 2 },
                { {1,0,0}, 1 },
                { {0,0,1}, 0 },
                { {1,0,0}, 2 },
                { {1,0,1}, 1 }
            }
        },
        {            /* 45 */
            4,
            {
                { {1,0,0}, 2 },
                { {1,0,1}, 1 },
                { {0,0,1}, 0 },
                { {0,0,0}, 0 },
                { {1,1,0}, 2 },
                { {1,0,0}, 1 },
                { {0,0,0}, 0 },
                { {0,0,0}, 2 },
                { {1,1,0}, 2 },
                { {0,0,0}, 2 },
                { {0,1,0}, 2 },
                { {1,1,0}, 2 }
            }
        },
        {            /* 46 */
            4,
            {
                { {0,0,0}, 0 },
                { {1,0,1}, 1 },
                { {0,0,1}, 0 },
                { {1,0,1}, 1 },
                { {0,0,0}, 0 },
                { {0,1,0}, 2 },
                { {0,0,0}, 0 },
                { {0,0,0}, 1 },
                { {0,1,0}, 2 },
                { {1,0,1}, 1 },
                { {0,1,0}, 2 },
                { {1,1,0}, 2 }
            }
        },
        {            /* 47 */
            3,
            {
                { {0,0,1}, 0 },
                { {1,1,0}, 2 },
                { {1,0,1}, 1 },
                { {0,0,1}, 0 },
                { {0,0,0}, 2 },
                { {1,1,0}, 2 },
                { {0,0,0}, 2 },
                { {0,1,0}, 2 },
                { {1,1,0}, 2 }
            }
        },
        {            /* 48 */
            2,
            {
                { {0,0,0}, 2 },
                { {1,0,1}, 1 },
                { {0,0,1}, 1 },
                { {0,0,0}, 2 },
                { {1,0,0}, 2 },
                { {1,0,1}, 1 }
            }
        },
        {            /* 49 */
            3,
            {
                { {0,0,0}, 0 },
                { {1,0,0}, 2 },
                { {1,0,1}, 1 },
                { {0,0,0}, 0 },
                { {1,0,1}, 1 },
                { {0,0,0}, 1 },
                { {0,0,0}, 1 },
                { {1,0,1}, 1 },
                { {0,0,1}, 1 }
            }
        },
        {            /* 50 */
            3,
            {
                { {0,0,0}, 2 },
                { {0,0,0}, 0 },
                { {1,0,0}, 1 },
                { {0,0,0}, 2 },
                { {1,0,0}, 1 },
                { {0,0,1}, 1 },
                { {0,0,1}, 1 },
                { {1,0,0}, 1 },
                { {1,0,1}, 1 }
            }
        },
        {            /* 51 */
            2,
            {
                { {0,0,0}, 1 },
                { {1,0,0}, 1 },
                { {0,0,1}, 1 },
                { {1,0,0}, 1 },
                { {1,0,1}, 1 },
                { {0,0,1}, 1 }
            }
        },
        {            /* 52 */
            3,
            {
                { {1,0,0}, 2 },
                { {1,0,1}, 1 },
                { {0,0,1}, 1 },
                { {1,0,0}, 2 },
                { {0,0,1}, 1 },
                { {0,0,0}, 2 },
                { {0,1,0}, 0 },
                { {0,0,0}, 1 },
                { {0,1,0}, 2 }
            }
        },
        {            /* 53 */
            4,
            {
                { {0,0,0}, 0 },
                { {0,1,0}, 2 },
                { {0,1,0}, 0 },
                { {0,1,0}, 2 },
                { {0,0,0}, 0 },
                { {1,0,1}, 1 },
                { {0,0,0}, 0 },
                { {1,0,0}, 2 },
                { {1,0,1}, 1 },
                { {0,1,0}, 2 },
                { {1,0,1}, 1 },
                { {0,0,1}, 1 }
            }
        },
        {            /* 54 */
            4,
            {
                { {0,0,0}, 1 },
                { {0,1,0}, 2 },
                { {0,1,0}, 0 },
                { {0,0,0}, 2 },
                { {0,0,0}, 0 },
                { {1,0,0}, 1 },
                { {0,0,0}, 2 },
                { {1,0,0}, 1 },
                { {0,0,1}, 1 },
                { {0,0,1}, 1 },
                { {1,0,0}, 1 },
                { {1,0,1}, 1 }
            }
        },
        {            /* 55 */
            3,
            {
                { {0,1,0}, 2 },
                { {0,1,0}, 0 },
                { {1,0,0}, 1 },
                { {0,1,0}, 2 },
                { {1,0,0}, 1 },
                { {0,0,1}, 1 },
                { {0,0,1}, 1 },
                { {1,0,0}, 1 },
                { {1,0,1}, 1 }
            }
        },
        {            /* 56 */
            3,
            {
                { {0,0,0}, 2 },
                { {1,0,1}, 1 },
                { {0,0,1}, 1 },
                { {0,0,0}, 2 },
                { {1,0,0}, 2 },
                { {1,0,1}, 1 },
                { {0,1,0}, 0 },
                { {1,1,0}, 2 },
                { {1,0,0}, 1 }
            }
        },
        {            /* 57 */
            4,
            {
                { {1,0,0}, 1 },
                { {0,1,0}, 0 },
                { {1,1,0}, 2 },
                { {0,0,0}, 0 },
                { {1,0,0}, 2 },
                { {1,0,1}, 1 },
                { {0,0,0}, 0 },
                { {1,0,1}, 1 },
                { {0,0,0}, 1 },
                { {0,0,0}, 1 },
                { {1,0,1}, 1 },
                { {0,0,1}, 1 }
            }
        },
        {            /* 58 */
            4,
            {
                { {0,0,0}, 0 },
                { {0,1,0}, 0 },
                { {1,1,0}, 2 },
                { {1,1,0}, 2 },
                { {0,0,1}, 1 },
                { {0,0,0}, 0 },
                { {0,0,0}, 0 },
                { {0,0,1}, 1 },
                { {0,0,0}, 2 },
                { {1,1,0}, 2 },
                { {1,0,1}, 1 },
                { {0,0,1}, 1 }
            }
        },
        {            /* 59 */
            3,
            {
                { {0,1,0}, 0 },
                { {1,1,0}, 2 },
                { {1,0,1}, 1 },
                { {0,1,0}, 0 },
                { {1,0,1}, 1 },
                { {0,0,0}, 1 },
                { {0,0,0}, 1 },
                { {1,0,1}, 1 },
                { {0,0,1}, 1 }
            }
        },
        {            /* 60 */
            4,
            {
                { {0,0,0}, 2 },
                { {1,0,1}, 1 },
                { {0,0,1}, 1 },
                { {0,0,0}, 2 },
                { {1,0,0}, 2 },
                { {1,0,1}, 1 },
                { {0,0,0}, 1 },
                { {1,1,0}, 2 },
                { {1,0,0}, 1 },
                { {0,0,0}, 1 },
                { {0,1,0}, 2 },
                { {1,1,0}, 2 }
            }
        },
        {            /* 61 */
            3,
            {
                { {0,0,1}, 1 },
                { {0,1,0}, 2 },
                { {1,1,0}, 2 },
                { {0,0,1}, 1 },
                { {1,1,0}, 2 },
                { {1,0,1}, 1 },
                { {0,0,0}, 0 },
                { {1,0,0}, 2 },
                { {1,0,0}, 1 }
            }
        },
        {            /* 62 */
            3,
            {
                { {1,0,1}, 1 },
                { {0,1,0}, 2 },
                { {1,1,0}, 2 },
                { {1,0,1}, 1 },
                { {0,0,1}, 1 },
                { {0,1,0}, 2 },
                { {0,0,0}, 0 },
                { {0,0,0}, 1 },
                { {0,0,0}, 2 }
            }
        },
        {            /* 63 */
            2,
            {
                { {0,0,1}, 1 },
                { {0,1,0}, 2 },
                { {1,1,0}, 2 },
                { {0,0,1}, 1 },
                { {1,1,0}, 2 },
                { {1,0,1}, 1 }
            }
        },
        {            /* 64 */
            1,
            {
                { {0,0,1}, 1 },
                { {0,1,1}, 0 },
                { {0,1,0}, 2 }
            }
        },
        {            /* 65 */
            2,
            {
                { {0,0,0}, 0 },
                { {0,0,0}, 2 },
                { {0,0,0}, 1 },
                { {0,0,1}, 1 },
                { {0,1,1}, 0 },
                { {0,1,0}, 2 }
            }
        },
        {            /* 66 */
            2,
            {
                { {0,0,0}, 0 },
                { {1,0,0}, 1 },
                { {1,0,0}, 2 },
                { {0,0,1}, 1 },
                { {0,1,1}, 0 },
                { {0,1,0}, 2 }
            }
        },
        {            /* 67 */
            3,
            {
                { {1,0,0}, 2 },
                { {0,0,0}, 1 },
                { {1,0,0}, 1 },
                { {1,0,0}, 2 },
                { {0,0,0}, 2 },
                { {0,0,0}, 1 },
                { {0,1,1}, 0 },
                { {0,1,0}, 2 },
                { {0,0,1}, 1 }
            }
        },
        {            /* 68 */
            2,
            {
                { {0,0,0}, 1 },
                { {0,1,1}, 0 },
                { {0,1,0}, 0 },
                { {0,0,0}, 1 },
                { {0,0,1}, 1 },
                { {0,1,1}, 0 }
            }
        },
        {            /* 69 */
            3,
            {
                { {0,0,0}, 2 },
                { {0,0,1}, 1 },
                { {0,1,1}, 0 },
                { {0,0,0}, 2 },
                { {0,1,1}, 0 },
                { {0,0,0}, 0 },
                { {0,0,0}, 0 },
                { {0,1,1}, 0 },
                { {0,1,0}, 0 }
            }
        },
        {            /* 70 */
            3,
            {
                { {0,0,1}, 1 },
                { {0,1,1}, 0 },
                { {0,1,0}, 0 },
                { {0,0,1}, 1 },
                { {0,1,0}, 0 },
                { {0,0,0}, 1 },
                { {1,0,0}, 2 },
                { {0,0,0}, 0 },
                { {1,0,0}, 1 }
            }
        },
        {            /* 71 */
            4,
            {
                { {0,0,0}, 2 },
                { {1,0,0}, 1 },
                { {1,0,0}, 2 },
                { {1,0,0}, 1 },
                { {0,0,0}, 2 },
                { {0,1,1}, 0 },
                { {0,0,0}, 2 },
                { {0,0,1}, 1 },
                { {0,1,1}, 0 },
                { {1,0,0}, 1 },
                { {0,1,1}, 0 },
                { {0,1,0}, 0 }
            }
        },
        {            /* 72 */
            2,
            {
                { {0,0,1}, 1 },
                { {0,1,1}, 0 },
                { {0,1,0}, 2 },
                { {0,1,0}, 0 },
                { {1,1,0}, 2 },
                { {1,0,0}, 1 }
            }
        },
        {            /* 73 */
            3,
            {
                { {1,0,0}, 1 },
                { {0,1,0}, 0 },
                { {1,1,0}, 2 },
                { {0,0,0}, 0 },
                { {0,0,0}, 2 },
                { {0,0,0}, 1 },
                { {0,1,1}, 0 },
                { {0,1,0}, 2 },
                { {0,0,1}, 1 }
            }
        },
        {            /* 74 */
            3,
            {
                { {0,0,0}, 0 },
                { {1,1,0}, 2 },
                { {1,0,0}, 2 },
                { {0,0,0}, 0 },
                { {0,1,0}, 0 },
                { {1,1,0}, 2 },
                { {0,0,1}, 1 },
                { {0,1,1}, 0 },
                { {0,1,0}, 2 }
            }
        },
        {            /* 75 */
            4,
            {
                { {0,1,0}, 2 },
                { {0,0,1}, 1 },
                { {0,1,1}, 0 },
                { {0,0,0}, 1 },
                { {0,1,0}, 0 },
                { {1,1,0}, 2 },
                { {0,0,0}, 1 },
                { {1,1,0}, 2 },
                { {0,0,0}, 2 },
                { {0,0,0}, 2 },
                { {1,1,0}, 2 },
                { {1,0,0}, 2 }
            }
        },
        {            /* 76 */
            3,
            {
                { {0,1,1}, 0 },
                { {1,1,0}, 2 },
                { {1,0,0}, 1 },
                { {0,1,1}, 0 },
                { {1,0,0}, 1 },
                { {0,0,1}, 1 },
                { {0,0,1}, 1 },
                { {1,0,0}, 1 },
                { {0,0,0}, 1 }
            }
        },
        {            /* 77 */
            4,
            {
                { {0,0,1}, 1 },
                { {0,0,0}, 0 },
                { {0,0,0}, 2 },
                { {0,0,1}, 1 },
                { {0,1,1}, 0 },
                { {0,0,0}, 0 },
                { {0,1,1}, 0 },
                { {1,0,0}, 1 },
                { {0,0,0}, 0 },
                { {0,1,1}, 0 },
                { {1,1,0}, 2 },
                { {1,0,0}, 1 }
            }
        },
        {            /* 78 */
            4,
            {
                { {0,0,0}, 1 },
                { {0,0,1}, 1 },
                { {0,1,1}, 0 },
                { {0,1,1}, 0 },
                { {1,0,0}, 2 },
                { {0,0,0}, 1 },
                { {0,0,0}, 1 },
                { {1,0,0}, 2 },
                { {0,0,0}, 0 },
                { {0,1,1}, 0 },
                { {1,1,0}, 2 },
                { {1,0,0}, 2 }
            }
        },
        {            /* 79 */
            3,
            {
                { {0,0,1}, 1 },
                { {0,1,1}, 0 },
                { {1,1,0}, 2 },
                { {0,0,1}, 1 },
                { {1,1,0}, 2 },
                { {0,0,0}, 2 },
                { {0,0,0}, 2 },
                { {1,1,0}, 2 },
                { {1,0,0}, 2 }
            }
        },
        {            /* 80 */
            2,
            {
                { {0,0,0}, 2 },
                { {0,0,1}, 0 },
                { {0,1,1}, 0 },
                { {0,0,0}, 2 },
                { {0,1,1}, 0 },
                { {0,1,0}, 2 }
            }
        },
        {            /* 81 */
            3,
            {
                { {0,0,0}, 1 },
                { {0,1,1}, 0 },
                { {0,1,0}, 2 },
                { {0,0,0}, 1 },
                { {0,0,0}, 0 },
                { {0,1,1}, 0 },
                { {0,0,0}, 0 },
                { {0,0,1}, 0 },
                { {0,1,1}, 0 }
            }
        },
        {            /* 82 */
            3,
            {
                { {0,1,0}, 2 },
                { {0,0,1}, 0 },
                { {0,1,1}, 0 },
                { {0,1,0}, 2 },
                { {0,0,0}, 2 },
                { {0,0,1}, 0 },
                { {1,0,0}, 1 },
                { {1,0,0}, 2 },
                { {0,0,0}, 0 }
            }
        },
        {            /* 83 */
            4,
            {
                { {0,0,0}, 1 },
                { {1,0,0}, 1 },
                { {1,0,0}, 2 },
                { {1,0,0}, 2 },
                { {0,1,1}, 0 },
                { {0,0,0}, 1 },
                { {0,0,0}, 1 },
                { {0,1,1}, 0 },
                { {0,1,0}, 2 },
                { {1,0,0}, 2 },
                { {0,0,1}, 0 },
                { {0,1,1}, 0 }
            }
        },
        {            /* 84 */
            3,
            {
                { {0,0,0}, 2 },
                { {0,1,0}, 0 },
                { {0,0,0}, 1 },
                { {0,0,0}, 2 },
                { {0,0,1}, 0 },
                { {0,1,0}, 0 },
                { {0,0,1}, 0 },
                { {0,1,1}, 0 },
                { {0,1,0}, 0 }
            }
        },
        {            /* 85 */
            2,
            {
                { {0,0,0}, 0 },
                { {0,0,1}, 0 },
                { {0,1,0}, 0 },
                { {0,1,0}, 0 },
                { {0,0,1}, 0 },
                { {0,1,1}, 0 }
            }
        },
        {            /* 86 */
            4,
            {
                { {0,0,0}, 0 },
                { {1,0,0}, 1 },
                { {1,0,0}, 2 },
                { {0,0,0}, 2 },
                { {0,1,0}, 0 },
                { {0,0,0}, 1 },
                { {0,0,0}, 2 },
                { {0,0,1}, 0 },
                { {0,1,0}, 0 },
                { {0,0,1}, 0 },
                { {0,1,1}, 0 },
                { {0,1,0}, 0 }
            }
        },
        {            /* 87 */
            3,
            {
                { {1,0,0}, 2 },
                { {0,1,0}, 0 },
                { {1,0,0}, 1 },
                { {1,0,0}, 2 },
                { {0,0,1}, 0 },
                { {0,1,0}, 0 },
                { {0,0,1}, 0 },
                { {0,1,1}, 0 },
                { {0,1,0}, 0 }
            }
        },
        {            /* 88 */
            3,
            {
                { {0,0,0}, 2 },
                { {0,0,1}, 0 },
                { {0,1,1}, 0 },
                { {0,0,0}, 2 },
                { {0,1,1}, 0 },
                { {0,1,0}, 2 },
                { {1,0,0}, 1 },
                { {0,1,0}, 0 },
                { {1,1,0}, 2 }
            }
        },
        {            /* 89 */
            4,
            {
                { {0,1,0}, 0 },
                { {1,1,0}, 2 },
                { {1,0,0}, 1 },
                { {0,0,0}, 1 },
                { {0,1,1}, 0 },
                { {0,1,0}, 2 },
                { {0,0,0}, 1 },
                { {0,0,0}, 0 },
                { {0,1,1}, 0 },
                { {0,0,0}, 0 },
                { {0,0,1}, 0 },
                { {0,1,1}, 0 }
            }
        },
        {            /* 90 */
            4,
            {
                { {0,0,0}, 2 },
                { {0,0,1}, 0 },
                { {0,1,1}, 0 },
                { {0,0,0}, 2 },
                { {0,1,1}, 0 },
                { {0,1,0}, 2 },
                { {0,0,0}, 0 },
                { {0,1,0}, 0 },
                { {1,1,0}, 2 },
                { {0,0,0}, 0 },
                { {1,1,0}, 2 },
                { {1,0,0}, 2 }
            }
        },
        {            /* 91 */
            3,
            {
                { {0,0,1}, 0 },
                { {1,1,0}, 2 },
                { {1,0,0}, 2 },
                { {0,0,1}, 0 },
                { {0,1,1}, 0 },
                { {1,1,0}, 2 },
                { {0,0,0}, 1 },
                { {0,1,0}, 0 },
                { {0,1,0}, 2 }
            }
        },
        {            /* 92 */
            4,
            {
                { {0,0,0}, 1 },
                { {1,1,0}, 2 },
                { {1,0,0}, 1 },
                { {1,1,0}, 2 },
                { {0,0,0}, 1 },
                { {0,0,1}, 0 },
                { {0,0,0}, 1 },
                { {0,0,0}, 2 },
                { {0,0,1}, 0 },
                { {1,1,0}, 2 },
                { {0,0,1}, 0 },
                { {0,1,1}, 0 }
            }
        },
        {            /* 93 */
            3,
            {
                { {1,0,0}, 1 },
                { {0,1,1}, 0 },
                { {1,1,0}, 2 },
                { {1,0,0}, 1 },
                { {0,0,0}, 0 },
                { {0,1,1}, 0 },
                { {0,0,0}, 0 },
                { {0,0,1}, 0 },
                { {0,1,1}, 0 }
            }
        },
        {            /* 94 */
            3,
            {
                { {0,1,1}, 0 },
                { {1,1,0}, 2 },
                { {1,0,0}, 2 },
                { {0,1,1}, 0 },
                { {1,0,0}, 2 },
                { {0,0,1}, 0 },
                { {0,0,0}, 1 },
                { {0,0,0}, 2 },
                { {0,0,0}, 0 }
            }
        },
        {            /* 95 */
            2,
            {
                { {0,0,1}, 0 },
                { {1,1,0}, 2 },
                { {1,0,0}, 2 },
                { {0,0,1}, 0 },
                { {0,1,1}, 0 },
                { {1,1,0}, 2 }
            }
        },
        {            /* 96 */
            2,
            {
                { {0,1,0}, 2 },
                { {0,0,1}, 1 },
                { {0,1,1}, 0 },
                { {0,0,1}, 0 },
                { {1,0,0}, 2 },
                { {1,0,1}, 1 }
            }
        },
        {            /* 97 */
            3,
            {
                { {1,0,1}, 1 },
                { {0,0,1}, 0 },
                { {1,0,0}, 2 },
                { {0,1,1}, 0 },
                { {0,1,0}, 2 },
                { {0,0,1}, 1 },
                { {0,0,0}, 0 },
                { {0,0,0}, 2 },
                { {0,0,0}, 1 }
            }
        },
        {            /* 98 */
            3,
            {
                { {0,0,0}, 0 },
                { {1,0,0}, 1 },
                { {1,0,1}, 1 },
                { {0,0,0}, 0 },
                { {1,0,1}, 1 },
                { {0,0,1}, 0 },
                { {0,1,0}, 2 },
                { {0,0,1}, 1 },
                { {0,1,1}, 0 }
            }
        },
        {            /* 99 */
            4,
            {
                { {0,0,1}, 1 },
                { {0,1,1}, 0 },
                { {0,1,0}, 2 },
                { {0,0,0}, 2 },
                { {1,0,1}, 1 },
                { {0,0,1}, 0 },
                { {0,0,0}, 2 },
                { {0,0,0}, 1 },
                { {1,0,1}, 1 },
                { {0,0,0}, 1 },
                { {1,0,0}, 1 },
                { {1,0,1}, 1 }
            }
        },
        {            /* 100 */
            3,
            {
                { {0,0,0}, 1 },
                { {0,1,1}, 0 },
                { {0,1,0}, 0 },
                { {0,0,0}, 1 },
                { {0,0,1}, 1 },
                { {0,1,1}, 0 },
                { {1,0,0}, 2 },
                { {1,0,1}, 1 },
                { {0,0,1}, 0 }
            }
        },
        {            /* 101 */
            4,
            {
                { {0,0,1}, 0 },
                { {1,0,0}, 2 },
                { {1,0,1}, 1 },
                { {0,0,0}, 2 },
                { {0,0,1}, 1 },
                { {0,1,1}, 0 },
                { {0,0,0}, 2 },
                { {0,1,1}, 0 },
                { {0,0,0}, 0 },
                { {0,0,0}, 0 },
                { {0,1,1}, 0 },
                { {0,1,0}, 0 }
            }
        },
        {            /* 102 */
            4,
            {
                { {0,0,0}, 1 },
                { {0,1,1}, 0 },
                { {0,1,0}, 0 },
                { {0,0,0}, 1 },
                { {0,0,1}, 1 },
                { {0,1,1}, 0 },
                { {0,0,0}, 0 },
                { {1,0,1}, 1 },
                { {0,0,1}, 0 },
                { {0,0,0}, 0 },
                { {1,0,0}, 1 },
                { {1,0,1}, 1 }
            }
        },
        {            /* 103 */
            3,
            {
                { {0,1,0}, 0 },
                { {1,0,0}, 1 },
                { {1,0,1}, 1 },
                { {0,1,0}, 0 },
                { {1,0,1}, 1 },
                { {0,1,1}, 0 },
                { {0,0,0}, 2 },
                { {0,0,1}, 1 },
                { {0,0,1}, 0 }
            }
        },
        {            /* 104 */
            3,
            {
                { {0,0,1}, 1 },
                { {0,1,1}, 0 },
                { {0,1,0}, 2 },
                { {0,0,1}, 0 },
                { {1,0,0}, 2 },
                { {1,0,1}, 1 },
                { {0,1,0}, 0 },
                { {1,1,0}, 2 },
                { {1,0,0}, 1 }
            }
        },
        {            /* 105 */
            4,
            {
                { {0,0,0}, 2 },
                { {0,0,0}, 1 },
                { {0,0,0}, 0 },
                { {0,0,1}, 1 },
                { {0,1,1}, 0 },
                { {0,1,0}, 2 },
                { {1,0,0}, 1 },
                { {0,1,0}, 0 },
                { {1,1,0}, 2 },
                { {0,0,1}, 0 },
                { {1,0,0}, 2 },
                { {1,0,1}, 1 }
            }
        },
        {            /* 106 */
            4,
            {
                { {0,1,1}, 0 },
                { {0,1,0}, 2 },
                { {0,0,1}, 1 },
                { {1,0,1}, 1 },
                { {0,1,0}, 0 },
                { {1,1,0}, 2 },
                { {1,0,1}, 1 },
                { {0,0,1}, 0 },
                { {0,1,0}, 0 },
                { {0,0,1}, 0 },
                { {0,0,0}, 0 },
                { {0,1,0}, 0 }
            }
        },
        {            /* 107 */
            3,
            {
                { {1,0,1}, 1 },
                { {0,1,1}, 0 },
                { {1,1,0}, 2 },
                { {0,0,1}, 0 },
                { {0,0,0}, 2 },
                { {0,0,1}, 1 },
                { {0,1,0}, 0 },
                { {0,1,0}, 2 },
                { {0,0,0}, 1 }
            }
        },
        {            /* 108 */
            4,
            {
                { {1,0,1}, 1 },
                { {0,0,1}, 0 },
                { {1,0,0}, 2 },
                { {0,1,1}, 0 },
                { {1,1,0}, 2 },
                { {1,0,0}, 1 },
                { {0,1,1}, 0 },
                { {1,0,0}, 1 },
                { {0,0,1}, 1 },
                { {0,0,1}, 1 },
                { {1,0,0}, 1 },
                { {0,0,0}, 1 }
            }
        },
        {            /* 109 */
            3,
            {
                { {0,0,1}, 1 },
                { {0,0,1}, 0 },
                { {0,0,0}, 2 },
                { {0,1,1}, 0 },
                { {1,1,0}, 2 },
                { {1,0,1}, 1 },
                { {0,0,0}, 0 },
                { {1,0,0}, 2 },
                { {1,0,0}, 1 }
            }
        },
        {            /* 110 */
            3,
            {
                { {0,0,0}, 1 },
                { {0,0,1}, 0 },
                { {0,0,0}, 0 },
                { {0,0,0}, 1 },
                { {0,0,1}, 1 },
                { {0,0,1}, 0 },
                { {1,1,0}, 2 },
                { {1,0,1}, 1 },
                { {0,1,1}, 0 }
            }
        },
        {            /* 111 */
            2,
            {
                { {0,0,0}, 2 },
                { {0,0,1}, 1 },
                { {0,0,1}, 0 },
                { {0,1,1}, 0 },
                { {1,1,0}, 2 },
                { {1,0,1}, 1 }
            }
        },
        {            /* 112 */
            3,
            {
                { {0,1,1}, 0 },
                { {1,0,0}, 2 },
                { {1,0,1}, 1 },
                { {0,1,1}, 0 },
                { {0,1,0}, 2 },
                { {1,0,0}, 2 },
                { {0,1,0}, 2 },
                { {0,0,0}, 2 },
                { {1,0,0}, 2 }
            }
        },
        {            /* 113 */
            4,
            {
                { {0,0,0}, 1 },
                { {0,1,1}, 0 },
                { {0,1,0}, 2 },
                { {0,0,0}, 1 },
                { {0,0,0}, 0 },
                { {0,1,1}, 0 },
                { {0,0,0}, 0 },
                { {1,0,1}, 1 },
                { {0,1,1}, 0 },
                { {0,0,0}, 0 },
                { {1,0,0}, 2 },
                { {1,0,1}, 1 }
            }
        },
        {            /* 114 */
            4,
            {
                { {0,0,0}, 2 },
                { {0,1,1}, 0 },
                { {0,1,0}, 2 },
                { {0,1,1}, 0 },
                { {0,0,0}, 2 },
                { {1,0,0}, 1 },
                { {0,0,0}, 2 },
                { {0,0,0}, 0 },
                { {1,0,0}, 1 },
                { {0,1,1}, 0 },
                { {1,0,0}, 1 },
                { {1,0,1}, 1 }
            }
        },
        {            /* 115 */
            3,
            {
                { {0,1,0}, 2 },
                { {1,0,1}, 1 },
                { {0,1,1}, 0 },
                { {0,1,0}, 2 },
                { {0,0,0}, 1 },
                { {1,0,1}, 1 },
                { {0,0,0}, 1 },
                { {1,0,0}, 1 },
                { {1,0,1}, 1 }
            }
        },
        {            /* 116 */
            4,
            {
                { {0,0,0}, 2 },
                { {1,0,0}, 2 },
                { {1,0,1}, 1 },
                { {1,0,1}, 1 },
                { {0,1,0}, 0 },
                { {0,0,0}, 2 },
                { {0,0,0}, 2 },
                { {0,1,0}, 0 },
                { {0,0,0}, 1 },
                { {1,0,1}, 1 },
                { {0,1,1}, 0 },
                { {0,1,0}, 0 }
            }
        },
        {            /* 117 */
            3,
            {
                { {1,0,0}, 2 },
                { {1,0,1}, 1 },
                { {0,1,1}, 0 },
                { {1,0,0}, 2 },
                { {0,1,1}, 0 },
                { {0,0,0}, 0 },
                { {0,0,0}, 0 },
                { {0,1,1}, 0 },
                { {0,1,0}, 0 }
            }
        },
        {            /* 118 */
            3,
            {
                { {0,1,1}, 0 },
                { {1,0,0}, 1 },
                { {1,0,1}, 1 },
                { {0,1,1}, 0 },
                { {0,1,0}, 0 },
                { {1,0,0}, 1 },
                { {0,0,0}, 2 },
                { {0,0,0}, 0 },
                { {0,0,0}, 1 }
            }
        },
        {            /* 119 */
            2,
            {
                { {0,1,0}, 0 },
                { {1,0,0}, 1 },
                { {1,0,1}, 1 },
                { {0,1,0}, 0 },
                { {1,0,1}, 1 },
                { {0,1,1}, 0 }
            }
        },
        {            /* 120 */
            4,
            {
                { {1,1,0}, 2 },
                { {1,0,0}, 1 },
                { {0,1,0}, 0 },
                { {0,1,1}, 0 },
                { {1,0,0}, 2 },
                { {1,0,1}, 1 },
                { {0,1,1}, 0 },
                { {0,1,0}, 2 },
                { {1,0,0}, 2 },
                { {0,1,0}, 2 },
                { {0,0,0}, 2 },
                { {1,0,0}, 2 }
            }
        },
        {            /* 121 */
            3,
            {
                { {0,0,0}, 1 },
                { {0,1,0}, 0 },
                { {0,1,0}, 2 },
                { {0,0,0}, 0 },
                { {1,0,0}, 2 },
                { {1,0,0}, 1 },
                { {0,1,1}, 0 },
                { {1,1,0}, 2 },
                { {1,0,1}, 1 }
            }
        },
        {            /* 122 */
            3,
            {
                { {0,0,0}, 2 },
                { {0,0,0}, 0 },
                { {0,1,0}, 0 },
                { {0,0,0}, 2 },
                { {0,1,0}, 0 },
                { {0,1,0}, 2 },
                { {1,0,1}, 1 },
                { {0,1,1}, 0 },
                { {1,1,0}, 2 }
            }
        },
        {            /* 123 */
            2,
            {
                { {0,0,0}, 1 },
                { {0,1,0}, 0 },
                { {0,1,0}, 2 },
                { {0,1,1}, 0 },
                { {1,1,0}, 2 },
                { {1,0,1}, 1 }
            }
        },
        {            /* 124 */
            3,
            {
                { {0,0,0}, 2 },
                { {1,0,0}, 1 },
                { {0,0,0}, 1 },
                { {0,0,0}, 2 },
                { {1,0,0}, 2 },
                { {1,0,0}, 1 },
                { {0,1,1}, 0 },
                { {1,1,0}, 2 },
                { {1,0,1}, 1 }
            }
        },
        {            /* 125 */
            2,
            {
                { {0,0,0}, 0 },
                { {1,0,0}, 2 },
                { {1,0,0}, 1 },
                { {1,0,1}, 1 },
                { {0,1,1}, 0 },
                { {1,1,0}, 2 }
            }
        },
        {            /* 126 */
            2,
            {
                { {0,0,0}, 2 },
                { {0,0,0}, 0 },
                { {0,0,0}, 1 },
                { {0,1,1}, 0 },
                { {1,1,0}, 2 },
                { {1,0,1}, 1 }
            }
        },
        {            /* 127 */
            1,
            {
                { {0,1,1}, 0 },
                { {1,1,0}, 2 },
                { {1,0,1}, 1 }
            }
        },
        {            /* 128 */
            1,
            {
                { {0,1,1}, 0 },
                { {1,0,1}, 1 },
                { {1,1,0}, 2 }
            }
        },
        {            /* 129 */
            2,
            {
                { {0,0,0}, 2 },
                { {0,0,0}, 1 },
                { {0,0,0}, 0 },
                { {0,1,1}, 0 },
                { {1,0,1}, 1 },
                { {1,1,0}, 2 }
            }
        },
        {            /* 130 */
            2,
            {
                { {0,0,0}, 0 },
                { {1,0,0}, 1 },
                { {1,0,0}, 2 },
                { {1,0,1}, 1 },
                { {1,1,0}, 2 },
                { {0,1,1}, 0 }
            }
        },
        {            /* 131 */
            3,
            {
                { {0,0,0}, 2 },
                { {0,0,0}, 1 },
                { {1,0,0}, 1 },
                { {0,0,0}, 2 },
                { {1,0,0}, 1 },
                { {1,0,0}, 2 },
                { {0,1,1}, 0 },
                { {1,0,1}, 1 },
                { {1,1,0}, 2 }
            }
        },
        {            /* 132 */
            2,
            {
                { {0,0,0}, 1 },
                { {0,1,0}, 2 },
                { {0,1,0}, 0 },
                { {0,1,1}, 0 },
                { {1,0,1}, 1 },
                { {1,1,0}, 2 }
            }
        },
        {            /* 133 */
            3,
            {
                { {0,0,0}, 2 },
                { {0,1,0}, 0 },
                { {0,0,0}, 0 },
                { {0,0,0}, 2 },
                { {0,1,0}, 2 },
                { {0,1,0}, 0 },
                { {1,0,1}, 1 },
                { {1,1,0}, 2 },
                { {0,1,1}, 0 }
            }
        },
        {            /* 134 */
            3,
            {
                { {0,0,0}, 1 },
                { {0,1,0}, 2 },
                { {0,1,0}, 0 },
                { {0,0,0}, 0 },
                { {1,0,0}, 1 },
                { {1,0,0}, 2 },
                { {0,1,1}, 0 },
                { {1,0,1}, 1 },
                { {1,1,0}, 2 }
            }
        },
        {            /* 135 */
            4,
            {
                { {1,1,0}, 2 },
                { {0,1,1}, 0 },
                { {1,0,1}, 1 },
                { {0,1,0}, 0 },
                { {1,0,0}, 1 },
                { {1,0,0}, 2 },
                { {0,1,0}, 0 },
                { {1,0,0}, 2 },
                { {0,1,0}, 2 },
                { {0,1,0}, 2 },
                { {1,0,0}, 2 },
                { {0,0,0}, 2 }
            }
        },
        {            /* 136 */
            2,
            {
                { {0,1,0}, 0 },
                { {1,0,1}, 1 },
                { {1,0,0}, 1 },
                { {0,1,0}, 0 },
                { {0,1,1}, 0 },
                { {1,0,1}, 1 }
            }
        },
        {            /* 137 */
            3,
            {
                { {0,1,1}, 0 },
                { {1,0,1}, 1 },
                { {1,0,0}, 1 },
                { {0,1,1}, 0 },
                { {1,0,0}, 1 },
                { {0,1,0}, 0 },
                { {0,0,0}, 2 },
                { {0,0,0}, 1 },
                { {0,0,0}, 0 }
            }
        },
        {            /* 138 */
            3,
            {
                { {1,0,0}, 2 },
                { {0,1,1}, 0 },
                { {1,0,1}, 1 },
                { {1,0,0}, 2 },
                { {0,0,0}, 0 },
                { {0,1,1}, 0 },
                { {0,0,0}, 0 },
                { {0,1,0}, 0 },
                { {0,1,1}, 0 }
            }
        },
        {            /* 139 */
            4,
            {
                { {1,0,0}, 2 },
                { {0,0,0}, 2 },
                { {0,0,0}, 1 },
                { {0,0,0}, 1 },
                { {0,1,1}, 0 },
                { {1,0,0}, 2 },
                { {1,0,0}, 2 },
                { {0,1,1}, 0 },
                { {1,0,1}, 1 },
                { {0,0,0}, 1 },
                { {0,1,0}, 0 },
                { {0,1,1}, 0 }
            }
        },
        {            /* 140 */
            3,
            {
                { {0,1,0}, 2 },
                { {0,1,1}, 0 },
                { {1,0,1}, 1 },
                { {0,1,0}, 2 },
                { {1,0,1}, 1 },
                { {0,0,0}, 1 },
                { {0,0,0}, 1 },
                { {1,0,1}, 1 },
                { {1,0,0}, 1 }
            }
        },
        {            /* 141 */
            4,
            {
                { {0,1,0}, 2 },
                { {0,0,0}, 0 },
                { {0,0,0}, 2 },
                { {0,0,0}, 0 },
                { {0,1,0}, 2 },
                { {1,0,1}, 1 },
                { {0,1,0}, 2 },
                { {0,1,1}, 0 },
                { {1,0,1}, 1 },
                { {0,0,0}, 0 },
                { {1,0,1}, 1 },
                { {1,0,0}, 1 }
            }
        },
        {            /* 142 */
            4,
            {
                { {1,0,1}, 1 },
                { {1,0,0}, 2 },
                { {0,0,0}, 0 },
                { {1,0,1}, 1 },
                { {0,0,0}, 0 },
                { {0,1,1}, 0 },
                { {0,1,1}, 0 },
                { {0,0,0}, 0 },
                { {0,0,0}, 1 },
                { {0,1,1}, 0 },
                { {0,0,0}, 1 },
                { {0,1,0}, 2 }
            }
        },
        {            /* 143 */
            3,
            {
                { {0,1,1}, 0 },
                { {1,0,1}, 1 },
                { {1,0,0}, 2 },
                { {0,1,1}, 0 },
                { {1,0,0}, 2 },
                { {0,1,0}, 2 },
                { {0,1,0}, 2 },
                { {1,0,0}, 2 },
                { {0,0,0}, 2 }
            }
        },
        {            /* 144 */
            2,
            {
                { {0,0,0}, 2 },
                { {0,0,1}, 0 },
                { {0,0,1}, 1 },
                { {0,1,1}, 0 },
                { {1,0,1}, 1 },
                { {1,1,0}, 2 }
            }
        },
        {            /* 145 */
            3,
            {
                { {0,0,0}, 1 },
                { {0,0,0}, 0 },
                { {0,0,1}, 0 },
                { {0,0,0}, 1 },
                { {0,0,1}, 0 },
                { {0,0,1}, 1 },
                { {1,1,0}, 2 },
                { {0,1,1}, 0 },
                { {1,0,1}, 1 }
            }
        },
        {            /* 146 */
            3,
            {
                { {0,0,1}, 1 },
                { {0,0,0}, 2 },
                { {0,0,1}, 0 },
                { {0,1,1}, 0 },
                { {1,0,1}, 1 },
                { {1,1,0}, 2 },
                { {0,0,0}, 0 },
                { {1,0,0}, 1 },
                { {1,0,0}, 2 }
            }
        },
        {            /* 147 */
            4,
            {
                { {1,0,1}, 1 },
                { {1,1,0}, 2 },
                { {0,1,1}, 0 },
                { {0,0,1}, 0 },
                { {1,0,0}, 1 },
                { {1,0,0}, 2 },
                { {0,0,1}, 0 },
                { {0,0,1}, 1 },
                { {1,0,0}, 1 },
                { {0,0,1}, 1 },
                { {0,0,0}, 1 },
                { {1,0,0}, 1 }
            }
        },
        {            /* 148 */
            3,
            {
                { {1,0,1}, 1 },
                { {1,1,0}, 2 },
                { {0,1,1}, 0 },
                { {0,0,1}, 0 },
                { {0,0,1}, 1 },
                { {0,0,0}, 2 },
                { {0,1,0}, 0 },
                { {0,0,0}, 1 },
                { {0,1,0}, 2 }
            }
        },
        {            /* 149 */
            4,
            {
                { {0,1,1}, 0 },
                { {1,0,1}, 1 },
                { {1,1,0}, 2 },
                { {0,0,1}, 1 },
                { {0,1,0}, 2 },
                { {0,1,0}, 0 },
                { {0,0,1}, 1 },
                { {0,1,0}, 0 },
                { {0,0,1}, 0 },
                { {0,0,1}, 0 },
                { {0,1,0}, 0 },
                { {0,0,0}, 0 }
            }
        },
        {            /* 150 */
            4,
            {
                { {0,0,0}, 2 },
                { {0,0,1}, 0 },
                { {0,0,1}, 1 },
                { {0,0,0}, 1 },
                { {0,1,0}, 2 },
                { {0,1,0}, 0 },
                { {1,0,1}, 1 },
                { {1,1,0}, 2 },
                { {0,1,1}, 0 },
                { {0,0,0}, 0 },
                { {1,0,0}, 1 },
                { {1,0,0}, 2 }
            }
        },
        {            /* 151 */
            3,
            {
                { {0,0,1}, 1 },
                { {0,1,0}, 2 },
                { {0,1,1}, 0 },
                { {0,0,1}, 0 },
                { {1,0,1}, 1 },
                { {1,0,0}, 2 },
                { {0,1,0}, 0 },
                { {1,0,0}, 1 },
                { {1,1,0}, 2 }
            }
        },
        {            /* 152 */
            3,
            {
                { {0,1,0}, 0 },
                { {1,0,1}, 1 },
                { {1,0,0}, 1 },
                { {0,1,0}, 0 },
                { {0,1,1}, 0 },
                { {1,0,1}, 1 },
                { {0,0,0}, 2 },
                { {0,0,1}, 0 },
                { {0,0,1}, 1 }
            }
        },
        {            /* 153 */
            4,
            {
                { {0,0,0}, 1 },
                { {0,0,0}, 0 },
                { {0,0,1}, 0 },
                { {0,0,0}, 1 },
                { {0,0,1}, 0 },
                { {0,0,1}, 1 },
                { {0,1,0}, 0 },
                { {0,1,1}, 0 },
                { {1,0,1}, 1 },
                { {0,1,0}, 0 },
                { {1,0,1}, 1 },
                { {1,0,0}, 1 }
            }
        },
        {            /* 154 */
            4,
            {
                { {0,0,1}, 0 },
                { {0,0,1}, 1 },
                { {0,0,0}, 2 },
                { {1,0,0}, 2 },
                { {0,1,1}, 0 },
                { {1,0,1}, 1 },
                { {1,0,0}, 2 },
                { {0,0,0}, 0 },
                { {0,1,1}, 0 },
                { {0,0,0}, 0 },
                { {0,1,0}, 0 },
                { {0,1,1}, 0 }
            }
        },
        {            /* 155 */
            3,
            {
                { {0,0,0}, 1 },
                { {0,1,0}, 0 },
                { {0,1,1}, 0 },
                { {0,0,0}, 1 },
                { {0,1,1}, 0 },
                { {0,0,1}, 1 },
                { {1,0,0}, 2 },
                { {0,0,1}, 0 },
                { {1,0,1}, 1 }
            }
        },
        {            /* 156 */
            4,
            {
                { {0,0,1}, 1 },
                { {0,0,0}, 2 },
                { {0,0,1}, 0 },
                { {0,1,0}, 2 },
                { {0,1,1}, 0 },
                { {1,0,1}, 1 },
                { {0,1,0}, 2 },
                { {1,0,1}, 1 },
                { {0,0,0}, 1 },
                { {0,0,0}, 1 },
                { {1,0,1}, 1 },
                { {1,0,0}, 1 }
            }
        },
        {            /* 157 */
            3,
            {
                { {0,0,0}, 0 },
                { {1,0,1}, 1 },
                { {1,0,0}, 1 },
                { {0,0,0}, 0 },
                { {0,0,1}, 0 },
                { {1,0,1}, 1 },
                { {0,1,0}, 2 },
                { {0,1,1}, 0 },
                { {0,0,1}, 1 }
            }
        },
        {            /* 158 */
            3,
            {
                { {1,0,1}, 1 },
                { {1,0,0}, 2 },
                { {0,0,1}, 0 },
                { {0,1,1}, 0 },
                { {0,0,1}, 1 },
                { {0,1,0}, 2 },
                { {0,0,0}, 0 },
                { {0,0,0}, 1 },
                { {0,0,0}, 2 }
            }
        },
        {            /* 159 */
            2,
            {
                { {0,1,0}, 2 },
                { {0,1,1}, 0 },
                { {0,0,1}, 1 },
                { {0,0,1}, 0 },
                { {1,0,1}, 1 },
                { {1,0,0}, 2 }
            }
        },
        {            /* 160 */
            2,
            {
                { {0,0,1}, 0 },
                { {1,0,0}, 2 },
                { {1,1,0}, 2 },
                { {0,0,1}, 0 },
                { {1,1,0}, 2 },
                { {0,1,1}, 0 }
            }
        },
        {            /* 161 */
            3,
            {
                { {0,1,1}, 0 },
                { {1,0,0}, 2 },
                { {1,1,0}, 2 },
                { {0,1,1}, 0 },
                { {0,0,1}, 0 },
                { {1,0,0}, 2 },
                { {0,0,0}, 1 },
                { {0,0,0}, 0 },
                { {0,0,0}, 2 }
            }
        },
        {            /* 162 */
            3,
            {
                { {1,0,0}, 1 },
                { {1,1,0}, 2 },
                { {0,1,1}, 0 },
                { {1,0,0}, 1 },
                { {0,1,1}, 0 },
                { {0,0,0}, 0 },
                { {0,0,0}, 0 },
                { {0,1,1}, 0 },
                { {0,0,1}, 0 }
            }
        },
        {            /* 163 */
            4,
            {
                { {1,0,0}, 1 },
                { {0,0,0}, 2 },
                { {0,0,0}, 1 },
                { {0,0,0}, 2 },
                { {1,0,0}, 1 },
                { {0,1,1}, 0 },
                { {1,0,0}, 1 },
                { {1,1,0}, 2 },
                { {0,1,1}, 0 },
                { {0,0,0}, 2 },
                { {0,1,1}, 0 },
                { {0,0,1}, 0 }
            }
        },
        {            /* 164 */
            3,
            {
                { {0,0,1}, 0 },
                { {1,0,0}, 2 },
                { {1,1,0}, 2 },
                { {0,0,1}, 0 },
                { {1,1,0}, 2 },
                { {0,1,1}, 0 },
                { {0,0,0}, 1 },
                { {0,1,0}, 2 },
                { {0,1,0}, 0 }
            }
        },
        {            /* 165 */
            4,
            {
                { {0,0,0}, 2 },
                { {0,1,0}, 0 },
                { {0,0,0}, 0 },
                { {0,0,0}, 2 },
                { {0,1,0}, 2 },
                { {0,1,0}, 0 },
                { {0,0,1}, 0 },
                { {1,1,0}, 2 },
                { {0,1,1}, 0 },
                { {0,0,1}, 0 },
                { {1,0,0}, 2 },
                { {1,1,0}, 2 }
            }
        },
        {            /* 166 */
            4,
            {
                { {0,1,0}, 0 },
                { {0,0,0}, 1 },
                { {0,1,0}, 2 },
                { {1,0,0}, 1 },
                { {1,1,0}, 2 },
                { {0,1,1}, 0 },
                { {1,0,0}, 1 },
                { {0,1,1}, 0 },
                { {0,0,0}, 0 },
                { {0,0,0}, 0 },
                { {0,1,1}, 0 },
                { {0,0,1}, 0 }
            }
        },
        {            /* 167 */
            3,
            {
                { {0,0,0}, 2 },
                { {0,1,1}, 0 },
                { {0,0,1}, 0 },
                { {0,0,0}, 2 },
                { {0,1,0}, 2 },
                { {0,1,1}, 0 },
                { {1,0,0}, 1 },
                { {1,1,0}, 2 },
                { {0,1,0}, 0 }
            }
        },
        {            /* 168 */
            3,
            {
                { {1,0,0}, 2 },
                { {1,0,0}, 1 },
                { {0,1,0}, 0 },
                { {1,0,0}, 2 },
                { {0,1,0}, 0 },
                { {0,0,1}, 0 },
                { {0,0,1}, 0 },
                { {0,1,0}, 0 },
                { {0,1,1}, 0 }
            }
        },
        {            /* 169 */
            4,
            {
                { {0,0,0}, 0 },
                { {0,0,0}, 2 },
                { {0,0,0}, 1 },
                { {1,0,0}, 2 },
                { {1,0,0}, 1 },
                { {0,1,0}, 0 },
                { {1,0,0}, 2 },
                { {0,1,0}, 0 },
                { {0,0,1}, 0 },
                { {0,0,1}, 0 },
                { {0,1,0}, 0 },
                { {0,1,1}, 0 }
            }
        },
        {            /* 170 */
            2,
            {
                { {0,0,0}, 0 },
                { {0,1,0}, 0 },
                { {0,0,1}, 0 },
                { {0,1,0}, 0 },
                { {0,1,1}, 0 },
                { {0,0,1}, 0 }
            }
        },
        {            /* 171 */
            3,
            {
                { {0,0,0}, 2 },
                { {0,0,0}, 1 },
                { {0,1,0}, 0 },
                { {0,0,0}, 2 },
                { {0,1,0}, 0 },
                { {0,0,1}, 0 },
                { {0,0,1}, 0 },
                { {0,1,0}, 0 },
                { {0,1,1}, 0 }
            }
        },
        {            /* 172 */
            4,
            {
                { {1,0,0}, 1 },
                { {0,0,0}, 1 },
                { {0,1,0}, 2 },
                { {0,1,0}, 2 },
                { {0,0,1}, 0 },
                { {1,0,0}, 1 },
                { {1,0,0}, 1 },
                { {0,0,1}, 0 },
                { {1,0,0}, 2 },
                { {0,1,0}, 2 },
                { {0,1,1}, 0 },
                { {0,0,1}, 0 }
            }
        },
        {            /* 173 */
            3,
            {
                { {0,1,0}, 2 },
                { {0,1,1}, 0 },
                { {0,0,1}, 0 },
                { {0,1,0}, 2 },
                { {0,0,1}, 0 },
                { {0,0,0}, 2 },
                { {1,0,0}, 1 },
                { {0,0,0}, 0 },
                { {1,0,0}, 2 }
            }
        },
        {            /* 174 */
            3,
            {
                { {0,0,0}, 1 },
                { {0,1,0}, 2 },
                { {0,1,1}, 0 },
                { {0,0,0}, 1 },
                { {0,1,1}, 0 },
                { {0,0,0}, 0 },
                { {0,0,0}, 0 },
                { {0,1,1}, 0 },
                { {0,0,1}, 0 }
            }
        },
        {            /* 175 */
            2,
            {
                { {0,0,0}, 2 },
                { {0,1,1}, 0 },
                { {0,0,1}, 0 },
                { {0,0,0}, 2 },
                { {0,1,0}, 2 },
                { {0,1,1}, 0 }
            }
        },
        {            /* 176 */
            3,
            {
                { {0,0,1}, 1 },
                { {1,1,0}, 2 },
                { {0,1,1}, 0 },
                { {0,0,1}, 1 },
                { {0,0,0}, 2 },
                { {1,1,0}, 2 },
                { {0,0,0}, 2 },
                { {1,0,0}, 2 },
                { {1,1,0}, 2 }
            }
        },
        {            /* 177 */
            4,
            {
                { {0,0,1}, 1 },
                { {0,0,0}, 1 },
                { {0,0,0}, 0 },
                { {0,0,0}, 0 },
                { {1,1,0}, 2 },
                { {0,0,1}, 1 },
                { {0,0,1}, 1 },
                { {1,1,0}, 2 },
                { {0,1,1}, 0 },
                { {0,0,0}, 0 },
                { {1,0,0}, 2 },
                { {1,1,0}, 2 }
            }
        },
        {            /* 178 */
            4,
            {
                { {1,0,0}, 1 },
                { {1,1,0}, 2 },
                { {0,1,1}, 0 },
                { {1,0,0}, 1 },
                { {0,1,1}, 0 },
                { {0,0,0}, 0 },
                { {0,0,0}, 0 },
                { {0,1,1}, 0 },
                { {0,0,1}, 1 },
                { {0,0,0}, 0 },
                { {0,0,1}, 1 },
                { {0,0,0}, 2 }
            }
        },
        {            /* 179 */
            3,
            {
                { {0,1,1}, 0 },
                { {1,0,0}, 1 },
                { {1,1,0}, 2 },
                { {0,1,1}, 0 },
                { {0,0,1}, 1 },
                { {1,0,0}, 1 },
                { {0,0,1}, 1 },
                { {0,0,0}, 1 },
                { {1,0,0}, 1 }
            }
        },
        {            /* 180 */
            4,
            {
                { {0,1,0}, 2 },
                { {0,1,0}, 0 },
                { {0,0,0}, 1 },
                { {0,0,1}, 1 },
                { {1,1,0}, 2 },
                { {0,1,1}, 0 },
                { {0,0,1}, 1 },
                { {0,0,0}, 2 },
                { {1,1,0}, 2 },
                { {0,0,0}, 2 },
                { {1,0,0}, 2 },
                { {1,1,0}, 2 }
            }
        },
        {            /* 181 */
            3,
            {
                { {0,0,0}, 0 },
                { {1,0,0}, 2 },
                { {1,1,0}, 2 },
                { {0,0,0}, 0 },
                { {1,1,0}, 2 },
                { {0,1,0}, 0 },
                { {0,0,1}, 1 },
                { {0,1,0}, 2 },
                { {0,1,1}, 0 }
            }
        },
        {            /* 182 */
            3,
            {
                { {1,0,0}, 1 },
                { {1,1,0}, 2 },
                { {0,1,0}, 0 },
                { {0,0,0}, 0 },
                { {0,0,0}, 1 },
                { {0,0,0}, 2 },
                { {0,1,1}, 0 },
                { {0,0,1}, 1 },
                { {0,1,0}, 2 }
            }
        },
        {            /* 183 */
            2,
            {
                { {0,0,1}, 1 },
                { {0,1,0}, 2 },
                { {0,1,1}, 0 },
                { {0,1,0}, 0 },
                { {1,0,0}, 1 },
                { {1,1,0}, 2 }
            }
        },
        {            /* 184 */
            4,
            {
                { {1,0,0}, 2 },
                { {0,0,1}, 1 },
                { {0,0,0}, 2 },
                { {0,0,1}, 1 },
                { {1,0,0}, 2 },
                { {0,1,0}, 0 },
                { {1,0,0}, 2 },
                { {1,0,0}, 1 },
                { {0,1,0}, 0 },
                { {0,0,1}, 1 },
                { {0,1,0}, 0 },
                { {0,1,1}, 0 }
            }
        },
        {            /* 185 */
            3,
            {
                { {0,0,1}, 1 },
                { {0,1,0}, 0 },
                { {0,1,1}, 0 },
                { {0,0,1}, 1 },
                { {0,0,0}, 1 },
                { {0,1,0}, 0 },
                { {1,0,0}, 2 },
                { {1,0,0}, 1 },
                { {0,0,0}, 0 }
            }
        },
        {            /* 186 */
            3,
            {
                { {0,0,0}, 2 },
                { {0,1,1}, 0 },
                { {0,0,1}, 1 },
                { {0,0,0}, 2 },
                { {0,0,0}, 0 },
                { {0,1,1}, 0 },
                { {0,0,0}, 0 },
                { {0,1,0}, 0 },
                { {0,1,1}, 0 }
            }
        },
        {            /* 187 */
            2,
            {
                { {0,0,0}, 1 },
                { {0,1,0}, 0 },
                { {0,1,1}, 0 },
                { {0,0,0}, 1 },
                { {0,1,1}, 0 },
                { {0,0,1}, 1 }
            }
        },
        {            /* 188 */
            3,
            {
                { {1,0,0}, 2 },
                { {1,0,0}, 1 },
                { {0,0,0}, 1 },
                { {1,0,0}, 2 },
                { {0,0,0}, 1 },
                { {0,0,0}, 2 },
                { {0,1,1}, 0 },
                { {0,0,1}, 1 },
                { {0,1,0}, 2 }
            }
        },
        {            /* 189 */
            2,
            {
                { {0,0,0}, 0 },
                { {1,0,0}, 2 },
                { {1,0,0}, 1 },
                { {0,0,1}, 1 },
                { {0,1,0}, 2 },
                { {0,1,1}, 0 }
            }
        },
        {            /* 190 */
            2,
            {
                { {0,0,0}, 0 },
                { {0,0,0}, 1 },
                { {0,0,0}, 2 },
                { {0,0,1}, 1 },
                { {0,1,0}, 2 },
                { {0,1,1}, 0 }
            }
        },
        {            /* 191 */
            1,
            {
                { {0,0,1}, 1 },
                { {0,1,0}, 2 },
                { {0,1,1}, 0 }
            }
        },
        {            /* 192 */
            2,
            {
                { {0,0,1}, 1 },
                { {1,1,0}, 2 },
                { {0,1,0}, 2 },
                { {0,0,1}, 1 },
                { {1,0,1}, 1 },
                { {1,1,0}, 2 }
            }
        },
        {            /* 193 */
            3,
            {
                { {1,0,1}, 1 },
                { {1,1,0}, 2 },
                { {0,1,0}, 2 },
                { {1,0,1}, 1 },
                { {0,1,0}, 2 },
                { {0,0,1}, 1 },
                { {0,0,0}, 0 },
                { {0,0,0}, 2 },
                { {0,0,0}, 1 }
            }
        },
        {            /* 194 */
            3,
            {
                { {0,0,1}, 1 },
                { {1,1,0}, 2 },
                { {0,1,0}, 2 },
                { {0,0,1}, 1 },
                { {1,0,1}, 1 },
                { {1,1,0}, 2 },
                { {0,0,0}, 0 },
                { {1,0,0}, 1 },
                { {1,0,0}, 2 }
            }
        },
        {            /* 195 */
            4,
            {
                { {0,0,0}, 2 },
                { {0,0,0}, 1 },
                { {1,0,0}, 1 },
                { {0,0,0}, 2 },
                { {1,0,0}, 1 },
                { {1,0,0}, 2 },
                { {0,0,1}, 1 },
                { {1,0,1}, 1 },
                { {1,1,0}, 2 },
                { {0,0,1}, 1 },
                { {1,1,0}, 2 },
                { {0,1,0}, 2 }
            }
        },
        {            /* 196 */
            3,
            {
                { {0,1,0}, 0 },
                { {1,0,1}, 1 },
                { {1,1,0}, 2 },
                { {0,1,0}, 0 },
                { {0,0,0}, 1 },
                { {1,0,1}, 1 },
                { {0,0,0}, 1 },
                { {0,0,1}, 1 },
                { {1,0,1}, 1 }
            }
        },
        {            /* 197 */
            4,
            {
                { {0,1,0}, 0 },
                { {0,0,0}, 0 },
                { {0,0,0}, 2 },
                { {0,0,0}, 2 },
                { {1,0,1}, 1 },
                { {0,1,0}, 0 },
                { {0,1,0}, 0 },
                { {1,0,1}, 1 },
                { {1,1,0}, 2 },
                { {0,0,0}, 2 },
                { {0,0,1}, 1 },
                { {1,0,1}, 1 }
            }
        },
        {            /* 198 */
            4,
            {
                { {1,0,0}, 1 },
                { {1,0,0}, 2 },
                { {0,0,0}, 0 },
                { {0,1,0}, 0 },
                { {1,0,1}, 1 },
                { {1,1,0}, 2 },
                { {0,1,0}, 0 },
                { {0,0,0}, 1 },
                { {1,0,1}, 1 },
                { {0,0,0}, 1 },
                { {0,0,1}, 1 },
                { {1,0,1}, 1 }
            }
        },
        {            /* 199 */
            3,
            {
                { {0,0,0}, 2 },
                { {0,0,1}, 1 },
                { {1,0,1}, 1 },
                { {0,0,0}, 2 },
                { {1,0,1}, 1 },
                { {1,0,0}, 2 },
                { {0,1,0}, 0 },
                { {1,0,0}, 1 },
                { {1,1,0}, 2 }
            }
        },
        {            /* 200 */
            3,
            {
                { {0,1,0}, 2 },
                { {1,0,0}, 1 },
                { {0,1,0}, 0 },
                { {0,1,0}, 2 },
                { {0,0,1}, 1 },
                { {1,0,0}, 1 },
                { {0,0,1}, 1 },
                { {1,0,1}, 1 },
                { {1,0,0}, 1 }
            }
        },
        {            /* 201 */
            4,
            {
                { {0,0,0}, 1 },
                { {0,0,0}, 0 },
                { {0,0,0}, 2 },
                { {0,1,0}, 2 },
                { {1,0,0}, 1 },
                { {0,1,0}, 0 },
                { {0,1,0}, 2 },
                { {0,0,1}, 1 },
                { {1,0,0}, 1 },
                { {0,0,1}, 1 },
                { {1,0,1}, 1 },
                { {1,0,0}, 1 }
            }
        },
        {            /* 202 */
            4,
            {
                { {0,1,0}, 0 },
                { {1,0,0}, 2 },
                { {0,0,0}, 0 },
                { {1,0,0}, 2 },
                { {0,1,0}, 0 },
                { {0,0,1}, 1 },
                { {0,1,0}, 0 },
                { {0,1,0}, 2 },
                { {0,0,1}, 1 },
                { {1,0,0}, 2 },
                { {0,0,1}, 1 },
                { {1,0,1}, 1 }
            }
        },
        {            /* 203 */
            3,
            {
                { {1,0,0}, 2 },
                { {0,0,1}, 1 },
                { {1,0,1}, 1 },
                { {1,0,0}, 2 },
                { {0,0,0}, 2 },
                { {0,0,1}, 1 },
                { {0,1,0}, 0 },
                { {0,1,0}, 2 },
                { {0,0,0}, 1 }
            }
        },
        {            /* 204 */
            2,
            {
                { {0,0,0}, 1 },
                { {0,0,1}, 1 },
                { {1,0,0}, 1 },
                { {1,0,0}, 1 },
                { {0,0,1}, 1 },
                { {1,0,1}, 1 }
            }
        },
        {            /* 205 */
            3,
            {
                { {0,0,0}, 2 },
                { {1,0,0}, 1 },
                { {0,0,0}, 0 },
                { {0,0,0}, 2 },
                { {0,0,1}, 1 },
                { {1,0,0}, 1 },
                { {0,0,1}, 1 },
                { {1,0,1}, 1 },
                { {1,0,0}, 1 }
            }
        },
        {            /* 206 */
            3,
            {
                { {0,0,0}, 0 },
                { {1,0,1}, 1 },
                { {1,0,0}, 2 },
                { {0,0,0}, 0 },
                { {0,0,0}, 1 },
                { {1,0,1}, 1 },
                { {0,0,0}, 1 },
                { {0,0,1}, 1 },
                { {1,0,1}, 1 }
            }
        },
        {            /* 207 */
            2,
            {
                { {0,0,0}, 2 },
                { {0,0,1}, 1 },
                { {1,0,1}, 1 },
                { {0,0,0}, 2 },
                { {1,0,1}, 1 },
                { {1,0,0}, 2 }
            }
        },
        {            /* 208 */
            3,
            {
                { {0,0,1}, 0 },
                { {1,0,1}, 1 },
                { {1,1,0}, 2 },
                { {0,0,1}, 0 },
                { {1,1,0}, 2 },
                { {0,0,0}, 2 },
                { {0,0,0}, 2 },
                { {1,1,0}, 2 },
                { {0,1,0}, 2 }
            }
        },
        {            /* 209 */
            4,
            {
                { {0,0,1}, 0 },
                { {0,0,0}, 1 },
                { {0,0,0}, 0 },
                { {0,0,0}, 1 },
                { {0,0,1}, 0 },
                { {1,1,0}, 2 },
                { {0,0,1}, 0 },
                { {1,0,1}, 1 },
                { {1,1,0}, 2 },
                { {0,0,0}, 1 },
                { {1,1,0}, 2 },
                { {0,1,0}, 2 }
            }
        },
        {            /* 210 */
            4,
            {
                { {1,0,0}, 2 },
                { {0,0,0}, 0 },
                { {1,0,0}, 1 },
                { {0,0,1}, 0 },
                { {1,0,1}, 1 },
                { {1,1,0}, 2 },
                { {0,0,1}, 0 },
                { {1,1,0}, 2 },
                { {0,0,0}, 2 },
                { {0,0,0}, 2 },
                { {1,1,0}, 2 },
                { {0,1,0}, 2 }
            }
        },
        {            /* 211 */
            3,
            {
                { {0,0,0}, 1 },
                { {1,1,0}, 2 },
                { {0,1,0}, 2 },
                { {0,0,0}, 1 },
                { {1,0,0}, 1 },
                { {1,1,0}, 2 },
                { {0,0,1}, 0 },
                { {1,0,1}, 1 },
                { {1,0,0}, 2 }
            }
        },
        {            /* 212 */
            4,
            {
                { {0,0,0}, 1 },
                { {0,0,0}, 2 },
                { {0,0,1}, 0 },
                { {0,0,0}, 1 },
                { {0,0,1}, 0 },
                { {0,1,0}, 0 },
                { {0,1,0}, 0 },
                { {0,0,1}, 0 },
                { {1,0,1}, 1 },
                { {0,1,0}, 0 },
                { {1,0,1}, 1 },
                { {1,1,0}, 2 }
            }
        },
        {            /* 213 */
            3,
            {
                { {1,0,1}, 1 },
                { {1,1,0}, 2 },
                { {0,1,0}, 0 },
                { {1,0,1}, 1 },
                { {0,1,0}, 0 },
                { {0,0,1}, 0 },
                { {0,0,1}, 0 },
                { {0,1,0}, 0 },
                { {0,0,0}, 0 }
            }
        },
        {            /* 214 */
            3,
            {
                { {0,0,0}, 1 },
                { {0,0,0}, 2 },
                { {0,0,0}, 0 },
                { {0,1,0}, 0 },
                { {1,0,0}, 1 },
                { {1,1,0}, 2 },
                { {0,0,1}, 0 },
                { {1,0,1}, 1 },
                { {1,0,0}, 2 }
            }
        },
        {            /* 215 */
            2,
            {
                { {0,0,1}, 0 },
                { {1,0,1}, 1 },
                { {1,0,0}, 2 },
                { {1,0,0}, 1 },
                { {1,1,0}, 2 },
                { {0,1,0}, 0 }
            }
        },
        {            /* 216 */
            4,
            {
                { {0,1,0}, 2 },
                { {0,0,0}, 2 },
                { {0,0,1}, 0 },
                { {0,0,1}, 0 },
                { {1,0,0}, 1 },
                { {0,1,0}, 2 },
                { {0,1,0}, 2 },
                { {1,0,0}, 1 },
                { {0,1,0}, 0 },
                { {0,0,1}, 0 },
                { {1,0,1}, 1 },
                { {1,0,0}, 1 }
            }
        },
        {            /* 217 */
            3,
            {
                { {0,0,1}, 0 },
                { {1,0,1}, 1 },
                { {1,0,0}, 1 },
                { {0,0,1}, 0 },
                { {1,0,0}, 1 },
                { {0,0,0}, 0 },
                { {0,1,0}, 2 },
                { {0,0,0}, 1 },
                { {0,1,0}, 0 }
            }
        },
        {            /* 218 */
            3,
            {
                { {0,1,0}, 2 },
                { {0,0,0}, 0 },
                { {0,1,0}, 0 },
                { {0,1,0}, 2 },
                { {0,0,0}, 2 },
                { {0,0,0}, 0 },
                { {1,0,1}, 1 },
                { {1,0,0}, 2 },
                { {0,0,1}, 0 }
            }
        },
        {            /* 219 */
            2,
            {
                { {0,0,0}, 1 },
                { {0,1,0}, 0 },
                { {0,1,0}, 2 },
                { {0,0,1}, 0 },
                { {1,0,1}, 1 },
                { {1,0,0}, 2 }
            }
        },
        {            /* 220 */
            3,
            {
                { {0,0,0}, 2 },
                { {0,0,1}, 0 },
                { {1,0,1}, 1 },
                { {0,0,0}, 2 },
                { {1,0,1}, 1 },
                { {0,0,0}, 1 },
                { {0,0,0}, 1 },
                { {1,0,1}, 1 },
                { {1,0,0}, 1 }
            }
        },
        {            /* 221 */
            2,
            {
                { {0,0,0}, 0 },
                { {1,0,1}, 1 },
                { {1,0,0}, 1 },
                { {0,0,0}, 0 },
                { {0,0,1}, 0 },
                { {1,0,1}, 1 }
            }
        },
        {            /* 222 */
            2,
            {
                { {0,0,0}, 1 },
                { {0,0,0}, 2 },
                { {0,0,0}, 0 },
                { {0,0,1}, 0 },
                { {1,0,1}, 1 },
                { {1,0,0}, 2 }
            }
        },
        {            /* 223 */
            1,
            {
                { {0,0,1}, 0 },
                { {1,0,1}, 1 },
                { {1,0,0}, 2 }
            }
        },
        {            /* 224 */
            3,
            {
                { {0,0,1}, 1 },
                { {0,0,1}, 0 },
                { {1,0,0}, 2 },
                { {0,0,1}, 1 },
                { {1,0,0}, 2 },
                { {0,1,0}, 2 },
                { {0,1,0}, 2 },
                { {1,0,0}, 2 },
                { {1,1,0}, 2 }
            }
        },
        {            /* 225 */
            4,
            {
                { {0,0,0}, 2 },
                { {0,0,0}, 1 },
                { {0,0,0}, 0 },
                { {0,0,1}, 1 },
                { {0,0,1}, 0 },
                { {1,0,0}, 2 },
                { {0,0,1}, 1 },
                { {1,0,0}, 2 },
                { {0,1,0}, 2 },
                { {0,1,0}, 2 },
                { {1,0,0}, 2 },
                { {1,1,0}, 2 }
            }
        },
        {            /* 226 */
            4,
            {
                { {0,0,1}, 0 },
                { {0,0,0}, 0 },
                { {1,0,0}, 1 },
                { {1,0,0}, 1 },
                { {0,1,0}, 2 },
                { {0,0,1}, 0 },
                { {0,0,1}, 0 },
                { {0,1,0}, 2 },
                { {0,0,1}, 1 },
                { {1,0,0}, 1 },
                { {1,1,0}, 2 },
                { {0,1,0}, 2 }
            }
        },
        {            /* 227 */
            3,
            {
                { {1,0,0}, 1 },
                { {1,1,0}, 2 },
                { {0,1,0}, 2 },
                { {1,0,0}, 1 },
                { {0,1,0}, 2 },
                { {0,0,0}, 1 },
                { {0,0,1}, 0 },
                { {0,0,0}, 2 },
                { {0,0,1}, 1 }
            }
        },
        {            /* 228 */
            4,
            {
                { {0,0,1}, 1 },
                { {0,1,0}, 0 },
                { {0,0,0}, 1 },
                { {0,1,0}, 0 },
                { {0,0,1}, 1 },
                { {1,0,0}, 2 },
                { {0,0,1}, 1 },
                { {0,0,1}, 0 },
                { {1,0,0}, 2 },
                { {0,1,0}, 0 },
                { {1,0,0}, 2 },
                { {1,1,0}, 2 }
            }
        },
        {            /* 229 */
            3,
            {
                { {0,1,0}, 0 },
                { {1,0,0}, 2 },
                { {1,1,0}, 2 },
                { {0,1,0}, 0 },
                { {0,0,0}, 0 },
                { {1,0,0}, 2 },
                { {0,0,1}, 1 },
                { {0,0,1}, 0 },
                { {0,0,0}, 2 }
            }
        },
        {            /* 230 */
            3,
            {
                { {0,0,1}, 1 },
                { {0,0,1}, 0 },
                { {0,0,0}, 0 },
                { {0,0,1}, 1 },
                { {0,0,0}, 0 },
                { {0,0,0}, 1 },
                { {1,1,0}, 2 },
                { {0,1,0}, 0 },
                { {1,0,0}, 1 }
            }
        },
        {            /* 231 */
            2,
            {
                { {0,0,0}, 2 },
                { {0,0,1}, 1 },
                { {0,0,1}, 0 },
                { {0,1,0}, 0 },
                { {1,0,0}, 1 },
                { {1,1,0}, 2 }
            }
        },
        {            /* 232 */
            4,
            {
                { {1,0,0}, 1 },
                { {0,0,1}, 0 },
                { {1,0,0}, 2 },
                { {1,0,0}, 1 },
                { {0,1,0}, 0 },
                { {0,0,1}, 0 },
                { {0,1,0}, 0 },
                { {0,0,1}, 1 },
                { {0,0,1}, 0 },
                { {0,1,0}, 0 },
                { {0,1,0}, 2 },
                { {0,0,1}, 1 }
            }
        },
        {            /* 233 */
            3,
            {
                { {1,0,0}, 1 },
                { {0,0,0}, 0 },
                { {1,0,0}, 2 },
                { {0,1,0}, 0 },
                { {0,1,0}, 2 },
                { {0,0,0}, 1 },
                { {0,0,1}, 0 },
                { {0,0,0}, 2 },
                { {0,0,1}, 1 }
            }
        },
        {            /* 234 */
            3,
            {
                { {0,0,1}, 1 },
                { {0,1,0}, 0 },
                { {0,1,0}, 2 },
                { {0,0,1}, 1 },
                { {0,0,1}, 0 },
                { {0,1,0}, 0 },
                { {0,0,1}, 0 },
                { {0,0,0}, 0 },
                { {0,1,0}, 0 }
            }
        },
        {            /* 235 */
            2,
            {
                { {0,0,1}, 0 },
                { {0,0,0}, 2 },
                { {0,0,1}, 1 },
                { {0,0,0}, 1 },
                { {0,1,0}, 0 },
                { {0,1,0}, 2 }
            }
        },
        {            /* 236 */
            3,
            {
                { {0,0,1}, 0 },
                { {1,0,0}, 2 },
                { {1,0,0}, 1 },
                { {0,0,1}, 0 },
                { {1,0,0}, 1 },
                { {0,0,1}, 1 },
                { {0,0,1}, 1 },
                { {1,0,0}, 1 },
                { {0,0,0}, 1 }
            }
        },
        {            /* 237 */
            2,
            {
                { {0,0,1}, 1 },
                { {0,0,1}, 0 },
                { {0,0,0}, 2 },
                { {0,0,0}, 0 },
                { {1,0,0}, 2 },
                { {1,0,0}, 1 }
            }
        },
        {            /* 238 */
            2,
            {
                { {0,0,0}, 1 },
                { {0,0,1}, 0 },
                { {0,0,0}, 0 },
                { {0,0,0}, 1 },
                { {0,0,1}, 1 },
                { {0,0,1}, 0 }
            }
        },
        {            /* 239 */
            1,
            {
                { {0,0,0}, 2 },
                { {0,0,1}, 1 },
                { {0,0,1}, 0 }
            }
        },
        {            /* 240 */
            2,
            {
                { {0,0,0}, 2 },
                { {1,0,0}, 2 },
                { {0,1,0}, 2 },
                { {1,0,0}, 2 },
                { {1,1,0}, 2 },
                { {0,1,0}, 2 }
            }
        },
        {            /* 241 */
            3,
            {
                { {0,0,0}, 1 },
                { {0,0,0}, 0 },
                { {1,0,0}, 2 },
                { {0,0,0}, 1 },
                { {1,0,0}, 2 },
                { {0,1,0}, 2 },
                { {0,1,0}, 2 },
                { {1,0,0}, 2 },
                { {1,1,0}, 2 }
            }
        },
        {            /* 242 */
            3,
            {
                { {0,0,0}, 0 },
                { {1,0,0}, 1 },
                { {1,1,0}, 2 },
                { {0,0,0}, 0 },
                { {1,1,0}, 2 },
                { {0,0,0}, 2 },
                { {0,0,0}, 2 },
                { {1,1,0}, 2 },
                { {0,1,0}, 2 }
            }
        },
        {            /* 243 */
            2,
            {
                { {0,0,0}, 1 },
                { {1,1,0}, 2 },
                { {0,1,0}, 2 },
                { {0,0,0}, 1 },
                { {1,0,0}, 1 },
                { {1,1,0}, 2 }
            }
        },
        {            /* 244 */
            3,
            {
                { {0,0,0}, 1 },
                { {1,1,0}, 2 },
                { {0,1,0}, 0 },
                { {0,0,0}, 1 },
                { {0,0,0}, 2 },
                { {1,1,0}, 2 },
                { {0,0,0}, 2 },
                { {1,0,0}, 2 },
                { {1,1,0}, 2 }
            }
        },
        {            /* 245 */
            2,
            {
                { {0,0,0}, 0 },
                { {1,0,0}, 2 },
                { {1,1,0}, 2 },
                { {0,0,0}, 0 },
                { {1,1,0}, 2 },
                { {0,1,0}, 0 }
            }
        },
        {            /* 246 */
            2,
            {
                { {0,0,0}, 2 },
                { {0,0,0}, 0 },
                { {0,0,0}, 1 },
                { {0,1,0}, 0 },
                { {1,0,0}, 1 },
                { {1,1,0}, 2 }
            }
        },
        {            /* 247 */
            1,
            {
                { {0,1,0}, 0 },
                { {1,0,0}, 1 },
                { {1,1,0}, 2 }
            }
        },
        {            /* 248 */
            3,
            {
                { {0,1,0}, 0 },
                { {1,0,0}, 2 },
                { {1,0,0}, 1 },
                { {0,1,0}, 0 },
                { {0,1,0}, 2 },
                { {1,0,0}, 2 },
                { {0,1,0}, 2 },
                { {0,0,0}, 2 },
                { {1,0,0}, 2 }
            }
        },
        {            /* 249 */
            2,
            {
                { {0,1,0}, 2 },
                { {0,0,0}, 1 },
                { {0,1,0}, 0 },
                { {0,0,0}, 0 },
                { {1,0,0}, 2 },
                { {1,0,0}, 1 }
            }
        },
        {            /* 250 */
            2,
            {
                { {0,0,0}, 2 },
                { {0,0,0}, 0 },
                { {0,1,0}, 0 },
                { {0,0,0}, 2 },
                { {0,1,0}, 0 },
                { {0,1,0}, 2 }
            }
        },
        {            /* 251 */
            1,
            {
                { {0,0,0}, 1 },
                { {0,1,0}, 0 },
                { {0,1,0}, 2 }
            }
        },
        {            /* 252 */
            2,
            {
                { {0,0,0}, 2 },
                { {1,0,0}, 1 },
                { {0,0,0}, 1 },
                { {0,0,0}, 2 },
                { {1,0,0}, 2 },
                { {1,0,0}, 1 }
            }
        },
        {            /* 253 */
            1,
            {
                { {0,0,0}, 0 },
                { {1,0,0}, 2 },
                { {1,0,0}, 1 }
            }
        },
        {            /* 254 */
            1,
            {
                { {0,0,0}, 2 },
                { {0,0,0}, 0 },
                { {0,0,0}, 1 }
            }
        },
        {            /* 255 */
            0,
            {
{{0}}
            }
        }
    };

private  int  get_voxel_case_struct(
    BOOLEAN             above_flags[2][2][2],
    voxel_point_type    *points_list_ptr[] );

public  int  compute_isotriangles_in_voxel(
    Real                corner_values[2][2][2],
    Real                target_value,
    voxel_point_type    *points_list_ptr[] )
{
    BOOLEAN   above_flags[2][2][2];

    above_flags[0][0][0] = (corner_values[0][0][0] >= target_value);
    above_flags[0][0][1] = (corner_values[0][0][1] >= target_value);
    above_flags[0][1][0] = (corner_values[0][1][0] >= target_value);
    above_flags[0][1][1] = (corner_values[0][1][1] >= target_value);
    above_flags[1][0][0] = (corner_values[1][0][0] >= target_value);
    above_flags[1][0][1] = (corner_values[1][0][1] >= target_value);
    above_flags[1][1][0] = (corner_values[1][1][0] >= target_value);
    above_flags[1][1][1] = (corner_values[1][1][1] >= target_value);

    return( get_voxel_case_struct( above_flags, points_list_ptr ) );
}

private  int  get_voxel_case_struct(
    BOOLEAN             above_flags[2][2][2],
    voxel_point_type    *points_list_ptr[] )
{
    int                         case_index;
    marching_cube_data_struct   *case_struct;

    case_index =  (above_flags[0][0][0] != FALSE) +
                 ((above_flags[1][0][0] != FALSE) << 1) +
                 ((above_flags[0][1][0] != FALSE) << 2) +
                 ((above_flags[1][1][0] != FALSE) << 3) +
                 ((above_flags[0][0][1] != FALSE) << 4) +
                 ((above_flags[1][0][1] != FALSE) << 5) +
                 ((above_flags[0][1][1] != FALSE) << 6) +
                 ((above_flags[1][1][1] != FALSE) << 7);

    case_struct = &marching_cube_cases[case_index];

    *points_list_ptr = case_struct->triangle_points;

    return( case_struct->n_triangles );
}
